import wx from 'weixin-js-sdk'
import * as API_WeiXin from '@/apis/weixin'
import * as API_Common from '@/apis/common'

import Qs from 'qs';
import request from '@/utils/request'
export function addSysLog(message) {

	return request({
		url: '/mobile/sysLogApi/submit',
		data: Qs.stringify({
			message: JSON.stringify(message)
		}),
		method: 'post',
	})
}
//获取微信配置
export function getWxConfig(jsApiList) {
	var jsApiList = jsApiList || ['chooseImage', 'getLocalImgData', 'scanQRCode'];
	let promise = (jsApiList => {
		return new Promise((resolve, reject) => {
			console.log(jsApiList);
			API_WeiXin.getConfig().then(response => {
				var wxconfig = response.wxConfig;
				console.log(wxconfig.nonceStr)
				wx.config({
					debug: false, // 开启调试模式,
					appId: wxconfig.appId, // 必填，企业号的唯一标识，此处填写企业号corpid
					timestamp: wxconfig.timestamp, // 必填，生成签名的时间戳
					nonceStr: wxconfig.nonceStr, // 必填，生成签名的随机串
					signature: wxconfig.signature, // 必填，签名，见附录1
					jsApiList: jsApiList // 必填，需要使用的JS接口列表，所有JS接口列表见附录2
				});
				wx.ready(function() {
					resolve(response);
				})
				wx.error(function(res) {
					reject('微信api配置出错');
				});
			}).catch(error => {
				mui.toast(error);
				reject(error);
			})
		})
	})(jsApiList)

	return promise;
}

//选择图片,多图上传和单图上传的回调处理不一样
export function chooseImage(count) {
	
	var count = count || 1;
	let promise = new Promise((resolve, reject) => {
		wx.chooseImage({
			count: count,
			sizeType: ['compressed'],
			sourceType: ['album', 'camera'],
			success: function(res) {
				var localIds = res.localIds;
				console.log(localIds);
				if (count == 1) {
					wx.getLocalImgData({
						localId: localIds[0],
						success: function(res) {
							resolve(res);
						}
					});
				} else {
					resolve(localIds);
				}
			}
		});
	});
	return promise;
}

//获取图片，用于多图上传时的递归处理
export function getLocalImgData(localId, fun) {
	wx.getLocalImgData({
		localId: localId,
		success: function(res) {
			fun(res);
		}
	});
}

//上传图片
export function uploadPic(imgBase64,compressBl) {
	//1,先将base64转换为blob
		   function dataURLtoBlob(dataurl){
		      var arr = dataurl.split(','),
		        mime = arr[0].match(/:(.*?);/)[1],
		        bstr = atob(arr[1]),
		        n = bstr.length,
		        u8arr = new Uint8Array(n);
		      while (n--) {
		        u8arr[n] = bstr.charCodeAt(n);
		      }
		      return new Blob([u8arr], { type: mime });
		    }
		    //2,再将blob转换为file
		  function  blobToFile(theBlob, fileName){
		       theBlob.lastModifiedDate = new Date();  // 文件最后的修改日期
		       theBlob.name = fileName;                // 文件名
		       return new File([theBlob], fileName, {type: theBlob.type, lastModified: Date.now()});
		    }
			
			/* 压缩base64图片 */
			function compress(
			  base64, // 源图片
			  rate, // 缩放比例
			  callback, // 回调
			 resolve, reject
			) {
			  //处理缩放，转格式
			  var _img = new Image();
			  _img.src = base64;//这里赋值之后就会触发onload函数
			  _img.onload = function () {
			    var _canvas = document.createElement('canvas');
			    var w = this.width * rate;
			    var h = this.height * rate;
			    _canvas.setAttribute('width', w);
			    _canvas.setAttribute('height', h);
			    _canvas.getContext('2d').drawImage(this, 0, 0, w, h);//this就是这个_img,在 这里画出缩小的图
			    var base64 = _canvas.toDataURL('image/jpeg');//然后把缩小的图转化为base64了，实现了图片的压缩
			    _canvas.toBlob(function (blob) {
			     
				  callback(base64,resolve, reject);
			    }, 'image/jpeg');
			  };
			} 
		function	thiscallback(imgBase64,resolve, reject){
			console.log(imgBase64.length)
			
			var formData = new FormData();
			formData.append('photoName', '1.jpg');
			//formData.append('photoBase64Data', imgBase64);
			var blob= dataURLtoBlob(imgBase64)
			var file= blobToFile(blob,'1.jpg')
			
			
			formData.append('photoFile', file);
			
			API_Common.upload(formData).then(response => {
				resolve(response);
			}).catch(error => {
				mui.toast(error);
				reject(error);
			})
		}
			
	let promise = new Promise((resolve, reject) => {
		console.log(imgBase64.length)
		
		if(compressBl){
			compress(imgBase64,0.6,thiscallback,resolve, reject)
			
		}else{
			thiscallback(imgBase64,resolve, reject)
		}
		
		
		
	
		
	});
	return promise;
}

//获取坐标
export function getLocation() {
	let promise = new Promise((resolve, reject) => {
		wx.ready(function() {
			wx.getLocation({
				type: 'gcj02', // 默认为wgs84的gps坐标，可传入'gcj02'
				success: function(res) {
					resolve(res);
				},
				faile: function(res) {
					reject(res);
				},
				fail: function(res) {
					if (res.errMsg == 'getLocation:timeout') {
						mui.alert("定位超时，请检查是否开启'定位'");
					} else if (res.errMsg == 'getLocation:ERROR_NETWORK') {
						mui.alert("网络异常");
					} else if (res.errMsg == 'getLocation:ERROR_NOCELL&WIFI_LOCATIONSWITCHOFF') {
						mui.alert("没开启系统定位");
					} else if (res.errMsg == 'getLocation:system permission denied') {
						mui.alert("未给微信位置授权");
					} else if (res.errMsg == 'getLocation:location permission') {
						mui.alert("未给微信位置授权");
					} else if (res.errMsg == 'getLocation:auth denied') {
						mui.alert("用户在小程序中未授权");
					} else if (res.errMsg == 'getLocation:fail authorize no response') {
						mui.alert("用户在小程序中未授权");
					}
					reject(res);
				},
				complete() {}
			})
		})
	})
	return promise;
}

//扫描二维码
export function scanQRCode(needResult) {
	var needResult = needResult || 1;
	let promise = new Promise((resolve, reject) => {
		wx.scanQRCode({
			needResult: needResult,
			scanType: ["qrCode"],
			success: function(res) {
				var url = res.resultStr;
				resolve(url);
			},
			faile: function(res) {
				reject(res);
			},
			fail: function(res) {


				if (res.errMsg == 'getLocation:timeout') {
					mui.alert("定位超时，请检查是否开启'定位'");
				} else if (res.errMsg == 'getLocation:ERROR_NETWORK') {
					mui.alert("网络异常");
				} else if (res.errMsg == 'getLocation:ERROR_NOCELL&WIFI_LOCATIONSWITCHOFF') {
					mui.alert("没开启系统定位");
				} else if (res.errMsg == 'getLocation:system permission denied') {
					mui.alert("未给微信位置授权");
				} else if (res.errMsg == 'getLocation:location permission') {
					mui.alert("未给微信位置授权");
				} else if (res.errMsg == 'getLocation:auth denied') {
					mui.alert("用户在小程序中未授权");
				} else if (res.errMsg == 'getLocation:fail authorize no response') {
					mui.alert("用户在小程序中未授权");
				}
				reject(res);
			},
			complete() {}
		})
	});
	return promise;
}
